# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spacex.api.device import device_pb2 as spacex_dot_api_dot_device_dot_device__pb2


class DeviceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Stream = channel.stream_stream(
                '/SpaceX.API.Device.Device/Stream',
                request_serializer=spacex_dot_api_dot_device_dot_device__pb2.ToDevice.SerializeToString,
                response_deserializer=spacex_dot_api_dot_device_dot_device__pb2.FromDevice.FromString,
                _registered_method=True)
        self.Handle = channel.unary_unary(
                '/SpaceX.API.Device.Device/Handle',
                request_serializer=spacex_dot_api_dot_device_dot_device__pb2.Request.SerializeToString,
                response_deserializer=spacex_dot_api_dot_device_dot_device__pb2.Response.FromString,
                _registered_method=True)


class DeviceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Stream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Handle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeviceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Stream': grpc.stream_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=spacex_dot_api_dot_device_dot_device__pb2.ToDevice.FromString,
                    response_serializer=spacex_dot_api_dot_device_dot_device__pb2.FromDevice.SerializeToString,
            ),
            'Handle': grpc.unary_unary_rpc_method_handler(
                    servicer.Handle,
                    request_deserializer=spacex_dot_api_dot_device_dot_device__pb2.Request.FromString,
                    response_serializer=spacex_dot_api_dot_device_dot_device__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'SpaceX.API.Device.Device', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('SpaceX.API.Device.Device', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Device(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Stream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/SpaceX.API.Device.Device/Stream',
            spacex_dot_api_dot_device_dot_device__pb2.ToDevice.SerializeToString,
            spacex_dot_api_dot_device_dot_device__pb2.FromDevice.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Handle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/SpaceX.API.Device.Device/Handle',
            spacex_dot_api_dot_device_dot_device__pb2.Request.SerializeToString,
            spacex_dot_api_dot_device_dot_device__pb2.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/services/unlock/service.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/services/unlock/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spacex/api/device/services/unlock/service.proto\x12!SpaceX.API.Device.Services.Unlock\"\xec\x01\n\x0fUnlockChallenge\x12\x1b\n\tdevice_id\x18\x01 \x01(\tR\x08\x64\x65viceId\x12\x14\n\x05nonce\x18\x02 \x01(\x0cR\x05nonce\x12\x1b\n\tsign_spki\x18\x04 \x01(\x0cR\x08signSpki\x12#\n\rgrant_keydata\x18\x05 \x01(\tR\x0cgrantKeydata\x12\'\n\x0fservice_keydata\x18\x06 \x01(\tR\x0eserviceKeydata\x12)\n\x10\x61uthority_grants\x18\x07 \x03(\tR\x0f\x61uthorityGrantsJ\x04\x08\x03\x10\x04R\ngrant_spki\"\x14\n\x12StartUnlockRequest\"e\n\x13StartUnlockResponse\x12\x1b\n\tdevice_id\x18\x01 \x01(\tR\x08\x64\x65viceId\x12\x14\n\x05nonce\x18\x02 \x01(\x0cR\x05nonce\x12\x1b\n\tsign_spki\x18\x03 \x01(\x0cR\x08signSpki\"Q\n\x13\x46inishUnlockRequest\x12\x1c\n\tchallenge\x18\x01 \x01(\x0cR\tchallenge\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\".\n\x14\x46inishUnlockResponse\x12\x16\n\x06status\x18\x01 \x01(\rR\x06status2\x8e\x02\n\rUnlockService\x12|\n\x0bStartUnlock\x12\x35.SpaceX.API.Device.Services.Unlock.StartUnlockRequest\x1a\x36.SpaceX.API.Device.Services.Unlock.StartUnlockResponse\x12\x7f\n\x0c\x46inishUnlock\x12\x36.SpaceX.API.Device.Services.Unlock.FinishUnlockRequest\x1a\x37.SpaceX.API.Device.Services.Unlock.FinishUnlockResponseB\xba\x02\n%com.SpaceX.API.Device.Services.UnlockB\x0cServiceProtoP\x01ZYgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device/services/unlock\xa2\x02\x05SADSU\xaa\x02!SpaceX.API.Device.Services.Unlock\xca\x02!SpaceX\\API\\Device\\Services\\Unlock\xe2\x02-SpaceX\\API\\Device\\Services\\Unlock\\GPBMetadata\xea\x02%SpaceX::API::Device::Services::Unlockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.services.unlock.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.SpaceX.API.Device.Services.UnlockB\014ServiceProtoP\001ZYgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device/services/unlock\242\002\005SADSU\252\002!SpaceX.API.Device.Services.Unlock\312\002!SpaceX\\API\\Device\\Services\\Unlock\342\002-SpaceX\\API\\Device\\Services\\Unlock\\GPBMetadata\352\002%SpaceX::API::Device::Services::Unlock'
  _globals['_UNLOCKCHALLENGE']._serialized_start=87
  _globals['_UNLOCKCHALLENGE']._serialized_end=323
  _globals['_STARTUNLOCKREQUEST']._serialized_start=325
  _globals['_STARTUNLOCKREQUEST']._serialized_end=345
  _globals['_STARTUNLOCKRESPONSE']._serialized_start=347
  _globals['_STARTUNLOCKRESPONSE']._serialized_end=448
  _globals['_FINISHUNLOCKREQUEST']._serialized_start=450
  _globals['_FINISHUNLOCKREQUEST']._serialized_end=531
  _globals['_FINISHUNLOCKRESPONSE']._serialized_start=533
  _globals['_FINISHUNLOCKRESPONSE']._serialized_end=579
  _globals['_UNLOCKSERVICE']._serialized_start=582
  _globals['_UNLOCKSERVICE']._serialized_end=852
# @@protoc_insertion_point(module_scope)
